<?php
include_once '../sys/inc/start.php';
include_once '../sys/inc/compress.php';
include_once '../sys/inc/sess.php';
include_once '../sys/inc/home.php';
include_once '../sys/inc/settings.php';
include_once '../sys/inc/db_connect.php';
include_once '../sys/inc/ipua.php';
include_once '../sys/inc/fnc.php';
include_once '../sys/inc/user.php';
$set['title']='Бармен онлайн';
include_once '../sys/inc/thead.php';
title();
aut();

if(!isset($user)){
  echo "Вы не зарегистрированы";
  include_once '../sys/inc/tfoot.php';
  break;
}

include_once 'inc/start.php';

if(isset($_POST['submit'])){
if(mysql_result(mysql_query("SELECT COUNT(*) FROM `bar_chat` WHERE `id_u`='".$user_id."' AND `time`>'".(time()-30)."'"),0)!=0)
bar_msg($diz['msg'],'Разрешено добавлять собщение не чаще, чем раз в пол минуты!');
else
{	
	
	
	if(mb_strlen($_POST['post'],'UTF-8')<5)
	bar_msg($diz['msg'],'Сообщение не может короче 5 символов!');
	else
	{
	
		if(mb_strlen($_POST['post'],'UTF-8')>512)
		bar_msg($diz['msg'],'Сообщение не может длинее 512 символов!');
		else
		{
			
			mysql_query("INSERT INTO `bar_chat`(`id_u`,`name`,`time`,`msg`) VALUES('".$user_id."','".$user_login."','".time()."','".mysql_real_escape_string($_POST['post'])."')");
		
		}
	
	}


}
}			
			
echo "
<div class='".$diz['main']."'>

<div class='".$diz['title2']."'>Чат</div>
";
$total=mysql_result(mysql_query("SELECT COUNT(*) FROM `bar_chat`"),0);
if($total>0){
$quert=mysql_query("SELECT * FROM `bar_chat` ORDER BY `id` DESC LIMIT ".$start.",5");

$i=0;
while($array=mysql_fetch_array($quert)){
$post=($i%2 ? $diz['post_1'] : $diz['post_2']);
echo '<div class="'.$post.'">
<table cellpadding="0">
<tr>
<td>
<img src="i/user_male.png"/>
</td>
<td>
<a href="profile.php?id='.$array['id_u'].'">'.$array['name'].'</a> ['.bar_date($array['time']).']
<br/>
'.bar_output($array['msg']).'
</td></tr></table></div>';
$i++;
}




if ($total > 5){
    echo bar_pagenav('chat.php?', $start, $total, 5);
   }
   }
   else
   echo "Сообщений нет! Будь первым!";
   
   echo "<br/><form method='post' action='chat.php?t=".mt_rand()."'>
   Сообщение (5-512 сим.)<br/>
   <textarea name='post'></textarea><br/>
   <input type='submit' name='submit' value='Отправить'/></form>";



echo "</div>";
ret($diz['title'],'Мой бар','index.php');
  include_once '../sys/inc/tfoot.php';
?>
